@@ -51,13 +51,14 @@ Categories=Game;'''
 class AppImageBuilder:
     '''This class provides tools for building and updating AppImages.'''
 
-    def __init__(self, cmd):
+    def __init__(self, cmd, name=None):
         '''The constructor.
 
         Arguments:
-        cmd -- the instance of the Panda3D's bdist_apps command.'''
+        cmd -- the instance of the Panda3D's bdist_apps command.
+        name -- the explicit name.'''
         self._cmd = cmd
-        self._name = cmd.distribution.get_name()
+        self._name = name or cmd.distribution.get_name()
 
     def build(self, longname=None, branch='', zsync_path=None):
         '''Builds an AppImage.
